<template>
  <a-card :bordered='false'>
    <!-- 查询区域 -->
    <div class='table-page-search-wrapper'>
      <a-form layout='inline' @keyup.enter.native='searchQuery'>
        <a-row :gutter='24'>
          <a-col :xl='6' :lg='7' :md='8' :sm='24'>
            <a-form-item label='项目编码'>
              <j-input placeholder='请输入项目编码' v-model='queryParam.code'></j-input>
            </a-form-item>
          </a-col>
          <a-col :xl='6' :lg='7' :md='8' :sm='24'>
            <a-form-item label='项目名称'>
              <j-input placeholder='请输入项目名称' v-model='queryParam.name'></j-input>
            </a-form-item>
          </a-col>
          <template v-if='toggleSearchStatus'>
            <a-col :xl='6' :lg='7' :md='8' :sm='24'>
              <a-form-item label='负责人'>
                <j-input placeholder='请输入负责人' v-model='queryParam.leader'></j-input>
              </a-form-item>
            </a-col>
            <a-col :xl='6' :lg='7' :md='8' :sm='24'>
              <a-form-item label='产品型号'>
                <j-input placeholder='请输入产品型号' v-model='queryParam.proModel'></j-input>
              </a-form-item>
            </a-col>
            <a-col :xl='6' :lg='7' :md='8' :sm='24'>
              <a-form-item label='提成系数'>
                <a-input placeholder='请输入提成系数' v-model='queryParam.coeff'></a-input>
              </a-form-item>
            </a-col>
            <a-col :xl='6' :lg='7' :md='8' :sm='24'>
              <a-form-item label='销售日期'>
<!--                <j-date placeholder='请选择销售日期' v-model='queryParam.sellDate'></j-date>-->
                <a-range-picker
                  v-model='queryParam.dateRange'
                  format='YYYY-MM-DD'
                  :placeholder="['开始时间', '结束时间']"
                  @change='onDateChange'>
                </a-range-picker>
              </a-form-item>
            </a-col>
            <a-col :xl='6' :lg='7' :md='8' :sm='24'>
              <a-form-item label='释放日期'>
<!--                <j-date placeholder='请选择释放日期' v-model='queryParam.releaseDate'></j-date>-->
                <a-range-picker
                  v-model='queryParam.dateRange2'
                  format='YYYY-MM-DD'
                  :placeholder="['开始时间', '结束时间']"
                  @change='onDateChange2'>
                </a-range-picker>
              </a-form-item>
            </a-col>
            <a-col :xl='6' :lg='7' :md='8' :sm='24'>
              <a-form-item label='当前阶段'>
<!--                <a-input placeholder='请输入当前阶段' v-model='queryParam.curStage'></a-input>-->
                <a-select v-model="queryParam.curStage">
                  <a-select-option :value="1">第一年(100%)</a-select-option>
                  <a-select-option :value="2">第二年(100%)</a-select-option>
                  <a-select-option :value="3">第三年(50%)</a-select-option>
                  <a-select-option :value="-1">过期</a-select-option>
                </a-select>
              </a-form-item>
            </a-col>

            <a-col :xl='6' :lg='7' :md='8' :sm='24'>
              <a-form-item label='备注'>
                <j-input placeholder='备注' v-model='queryParam.remark'></j-input>
              </a-form-item>
            </a-col>
          </template>
          <a-col :xl='6' :lg='7' :md='8' :sm='24'>
            <span style='float: left;overflow: hidden;' class='table-page-search-submitButtons'>
              <a-button type='primary' @click='searchQuery' icon='search'>查询</a-button>
              <a-button type='primary' @click='searchReset' icon='reload' style='margin-left: 8px'>重置</a-button>
              <a @click='handleToggleSearch' style='margin-left: 8px'>
                {{ toggleSearchStatus ? '收起' : '展开' }}
                <a-icon :type="toggleSearchStatus ? 'up' : 'down'" />
              </a>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class='table-operator'>
      <a-button @click='handleAdd' type='primary' icon='plus'>新增</a-button>
      <a-button type='primary' icon='download' @click="handleExportXls('bon_sale_record')">导出</a-button>
      <a-upload name='file' :showUploadList='false' :multiple='false' :headers='tokenHeader' :action='importExcelUrl'
                @change='handleImportExcel'>
        <a-button type='primary' icon='import'>导入</a-button>
      </a-upload>
      <!-- 高级查询区域 -->
      <j-super-query :fieldList='superFieldList' ref='superQueryModal'
                     @handleSuperQuery='handleSuperQuery'></j-super-query>
      <a-dropdown v-if='selectedRowKeys.length > 0'>
        <a-menu slot='overlay'>
          <a-menu-item key='1' @click='batchDel'>
            <a-icon type='delete' />
            删除
          </a-menu-item>
        </a-menu>
        <a-button style='margin-left: 8px'> 批量操作
          <a-icon type='down' />
        </a-button>
      </a-dropdown>


      <a-button @click='handlDel' type='primary' icon='plus'>删除全部</a-button>
      <a-button @click='handleCalc' type='primary' icon='plus'>计算奖金</a-button>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class='ant-alert ant-alert-info' style='margin-bottom: 16px;'>
        <i class='anticon anticon-info-circle ant-alert-icon'></i> 已选择 <a
        style='font-weight: 600'>{{ selectedRowKeys.length }}</a>项
        <a style='margin-left: 24px' @click='onClearSelected'>清空</a>
      </div>

      <a-table
        ref='table'
        size='middle'
        :scroll='{x:true}'
        bordered
        rowKey='id'
        :columns='columns'
        :dataSource='dataSource'
        :pagination='ipagination'
        :loading='loading'
        :rowSelection='{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}'
        class='j-table-force-nowrap'
        @change='handleTableChange'>

        <template slot='htmlSlot' slot-scope='text'>
          <div v-html='text'></div>
        </template>
        <template slot='imgSlot' slot-scope='text'>
          <span v-if='!text' style='font-size: 12px;font-style: italic;'>无图片</span>
          <img v-else :src='getImgView(text)' height='25px' alt=''
               style='max-width:80px;font-size: 12px;font-style: italic;' />
        </template>
        <template slot='fileSlot' slot-scope='text'>
          <span v-if='!text' style='font-size: 12px;font-style: italic;'>无文件</span>
          <a-button
            v-else
            :ghost='true'
            type='primary'
            icon='download'
            size='small'
            @click='downloadFile(text)'>
            下载
          </a-button>
        </template>

        <span slot='action' slot-scope='text, record'>
          <a @click='handleEdit(record)'>编辑</a>

          <a-divider type='vertical' />
          <a-dropdown>
            <a class='ant-dropdown-link'>更多 <a-icon type='down' /></a>
            <a-menu slot='overlay'>
              <a-menu-item>
                <a @click='handleDetail(record)'>详情</a>
              </a-menu-item>
              <a-menu-item>
                <a-popconfirm title='确定删除吗?' @confirm='() => handleDelete(record.id)'>
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>

      </a-table>
    </div>

    <bon-sale-record-modal ref='modalForm' @ok='modalFormOk'></bon-sale-record-modal>
  </a-card>
</template>

<script>

import '@/assets/less/TableExpand.less'
import { mixinDevice } from '@/utils/mixin'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import BonSaleRecordModal from './modules/BonSaleRecordModal'
import { getAction } from '@api/manage'

export default {
  name: 'BonSaleRecordList',
  mixins: [JeecgListMixin, mixinDevice],
  components: {
    BonSaleRecordModal
  },
  data() {
    return {
      description: 'bon_sale_record管理页面',
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '项目编码',
          align: 'center',
          dataIndex: 'code'
        },
        {
          title: '项目名称',
          align: 'center',
          dataIndex: 'name'
        },
        {
          title: '负责人',
          align: 'center',
          dataIndex: 'leader'
        },
        {
          title: '产品型号',
          align: 'center',
          dataIndex: 'proModel'
        },
        {
          title: '提成系数',
          align: 'center',
          dataIndex: 'coeff'
        },
        {
          title: '首售100日期',
          align: 'center',
          dataIndex: 'firstDate',
          customRender: function(text) {
            return !text ? '' : (text.length > 10 ? text.substr(0, 10) : text)
          }
        },
        {
          title: '释放日期',
          align: 'center',
          dataIndex: 'releaseDate',
          customRender: function(text) {
            return !text ? '' : (text.length > 10 ? text.substr(0, 10) : text)
          }
        },
        {
          title: '销售日期',
          align: 'center',
          dataIndex: 'sellDate',
          customRender: function(text) {
            return !text ? '' : (text.length > 10 ? text.substr(0, 10) : text)
          }
        },
        {
          title: '当期销售额',
          align: 'center',
          dataIndex: 'curSales'
        },
        {
          title: '当期奖金',
          align: 'center',
          dataIndex: 'curBonus'
        },
        {
          title: '当前阶段',
          align: 'center',
          dataIndex: 'curStage',
          customRender: function(text) {
            if(text==-1){
              return "已过期"
            }else  if(text == 1){
              return "第一年"
            }else  if(text == 2){
              return "第二年"
            }else  if(text == 3){
              return "第三年"
            }
            return  text
          }
        },
        {
          title: '备注',
          align: 'center',
          dataIndex: 'remark'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          fixed: 'right',
          width: 147,
          scopedSlots: { customRender: 'action' }
        }
      ],
      isorter: {
        column: 'code,sellDate',
        order: 'desc'
      },
      /* 分页参数 */
      ipagination: {
        current: 1,
        pageSize: 10,
        pageSizeOptions: ['10', '20', '30', '50', '100', '200', '500'],
        showTotal: (total, range) => {
          return range[0] + '-' + range[1] + ' 共' + total + '条'
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0
      },
      url: {
        list: '/bon/sale/list',
        delete: '/bon/sale/delete',
        deleteBatch: '/bon/sale/deleteBatch',
        exportXlsUrl: '/bon/sale/exportXls',
        importExcelUrl: 'bon/sale/importExcel',
        calc: '/bon/sale/calc',
        delall: '/bon/sale/delall',



      },
      dictOptions: {},
      superFieldList: []
    }
  },
  created() {
    this.getSuperFieldList()
  },
  computed: {
    importExcelUrl: function() {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`
    }
  },
  methods: {
    initDictConfig() {
    },
    getSuperFieldList() {
      let fieldList = []
      fieldList.push({ type: 'string', value: 'code', text: '项目编码', dictCode: '' })
      fieldList.push({ type: 'string', value: 'name', text: '项目名称', dictCode: '' })
      fieldList.push({ type: 'string', value: 'leader', text: '负责人', dictCode: '' })
      fieldList.push({ type: 'string', value: 'proModel', text: '产品型号', dictCode: '' })
      fieldList.push({ type: 'double', value: 'coeff', text: '提成系数', dictCode: '' })
      fieldList.push({ type: 'date', value: 'sellDate', text: '销售日期' })
      fieldList.push({ type: 'date', value: 'releaseDate', text: '释放日期' })
      fieldList.push({ type: 'BigDecimal', value: 'curSales', text: '当期销售额', dictCode: '' })
      fieldList.push({ type: 'BigDecimal', value: 'curBonus', text: '当期奖金', dictCode: '' })
      fieldList.push({ type: 'int', value: 'curStage', text: '当前阶段', dictCode: '' })
      this.superFieldList = fieldList
    },
    handleCalc() {
      getAction(this.url.calc, {}).then(res => {
        if (res.success) {
          this.loadData()
          this.$message.success(res.message)
        }else {
          this.$message.warning('计算失败')
        }

      })
    },
    handlDel(){
      let _this = this
      this.$confirm({
        title: '提示',
        content: '删除所有数据，此操作不可恢复！',
        okText: '删除',
        okType: 'danger',
        cancelText: '取消',
        onOk() {
          getAction(_this.url.delall, {}).then(res => {
            if (res.success) {
              _this.loadData()
              _this.$message.success(res.message)
            }else {
              _this.$message.warning('计算失败')
            }

          })
        },
        onCancel() {
          console.log('Cancel');
        },
      });
    },
    onDateChange: function(value, dateString) {
      this.queryParam.sellDate_begin = dateString[0]
      this.queryParam.sellDate_end = dateString[1]
      this.$forceUpdate()
    },
    onDateChange2: function(value, dateString) {
      this.queryParam.releaseDate_begin = dateString[0]
      this.queryParam.releaseDate_end = dateString[1]
      this.$forceUpdate()
    },

  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>